aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core
diff options
context:
space:
mode:
authorGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-24 18:28:34 +0000
committerGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-24 18:28:34 +0000
commita469c28c3c16214733a25201a286970f57b3d944 (patch)
tree2493bd735990ff40770ed8cfa601db0a2babe549 /include/core
parent96182216f187fd103392ccaa34f505fe54fcff7e (diff)
CustomStage Renaming Part 1
Search and replace: GrCustomStage->GrEffect GrCustomStageTestFactory->GrEffectTestFactory renamed the cpp/h files from customStage->effect reordered gypi, #includes, forward decls to maintain alphabetical sort. manually fixed up some whitespace and linewraps deleted a commented out #include R=robertphillips@google.com Review URL: https://codereview.appspot.com/6758046 git-svn-id: http://skia.googlecode.com/svn/trunk@6076 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/core')
-rw-r--r--include/core/SkColorFilter.h4
-rw-r--r--include/core/SkImageFilter.h8
-rw-r--r--include/core/SkShader.h6
3 files changed, 9 insertions, 9 deletions
diff --git a/include/core/SkColorFilter.h b/include/core/SkColorFilter.h
index f8163b2b57..d470672a3f 100644
--- a/include/core/SkColorFilter.h
+++ b/include/core/SkColorFilter.h
@@ -15,7 +15,7 @@
#include "SkXfermode.h"
class SkBitmap;
-class GrCustomStage;
+class GrEffect;
class GrContext;
class SK_API SkColorFilter : public SkFlattenable {
@@ -118,7 +118,7 @@ public:
/** A subclass may implement this factory function to work with the GPU backend. If the return
is non-NULL then the caller owns a ref on the returned object.
*/
- virtual GrCustomStage* asNewCustomStage(GrContext*) const;
+ virtual GrEffect* asNewCustomStage(GrContext*) const;
SK_DECLARE_FLATTENABLE_REGISTRAR_GROUP()
protected:
diff --git a/include/core/SkImageFilter.h b/include/core/SkImageFilter.h
index ecbf79dda3..f37d5a39fa 100644
--- a/include/core/SkImageFilter.h
+++ b/include/core/SkImageFilter.h
@@ -17,7 +17,7 @@ class SkMatrix;
struct SkIPoint;
struct SkIRect;
struct SkRect;
-class GrCustomStage;
+class GrEffect;
class GrTexture;
/**
@@ -83,14 +83,14 @@ public:
/**
* Returns true if the filter can be expressed a single-pass
* GrCustomStage, used to process this filter on the GPU, or false if
* not.
*
* If stage is non-NULL, a new GrCustomStage instance is stored
* in it. The caller assumes ownership of the stage, and it is up to the
* caller to unref it.
*/
- virtual bool asNewCustomStage(GrCustomStage** stage, GrTexture*) const;
+ virtual bool asNewCustomStage(GrEffect** stage, GrTexture*) const;
/**
* Returns true if the filter can be processed on the GPU. This is most
@@ -83,14 +83,14 @@ public:
/**
* Returns true if the filter can be expressed a single-pass
- * GrCustomStage, used to process this filter on the GPU, or false if
+ * GrEffect, used to process this filter on the GPU, or false if
* not.
*
@@ -83,14 +83,14 @@ public:
* not.
*
- * If stage is non-NULL, a new GrCustomStage instance is stored
+ * If stage is non-NULL, a new GrEffect instance is stored
* in it. The caller assumes ownership of the stage, and it is up to the
* caller to unref it.
diff --git a/include/core/SkShader.h b/include/core/SkShader.h
index a0a1b056d4..23e095029b 100644
--- a/include/core/SkShader.h
+++ b/include/core/SkShader.h
@@ -18,7 +18,7 @@
class SkPath;
class GrContext;
-class GrCustomStage;
+class GrEffect;
class GrSamplerState;
/** \class SkShader
@@ -306,11 +306,11 @@ public:
virtual GradientType asAGradient(GradientInfo* info) const;
/**
* If the shader subclass has a GrCustomStage implementation, this installs
* a custom stage on the sampler. A GrContext pointer is required since custom
* stages may need to create textures. The sampler parameter is necessary to set a
* texture matrix. It will eventually be removed and this function will operate as a
- * GrCustomStage factory.
+ * GrEffect factory.
*/
virtual bool asNewCustomStage(GrContext* context, GrSamplerState* sampler) const;
@@ -306,11 +306,11 @@ public:
virtual GradientType asAGradient(GradientInfo* info) const;
/**
- * If the shader subclass has a GrCustomStage implementation, this installs
+ * If the shader subclass has a GrEffect implementation, this installs
* a custom stage on the sampler. A GrContext pointer is required since custom
* stages may need to create textures. The sampler parameter is necessary to set a